@@ -62,39 +62,39 @@ void neon_generic_error_mapper(int ne_status, StatusCode::Code & code, std::stri
     switch(ne_status){
         case NE_OK:
             code = StatusCode::OK;
-            str= "Status Ok";
+            str = "Status Ok";
             break;
         case NE_LOOKUP:
-             code = StatusCode::NameResolutionFailure;
-             str= "Domain name resolution failed";
-             break;
+            code = StatusCode::NameResolutionFailure;
+            str = "Domain name resolution failed";
+            break;
         case NE_AUTH:
             code = StatusCode::AuthenticationError;
-            str = "Authentification failed on server";
+            str = "Authentication failed on server";
             break;
         case NE_PROXYAUTH:
             code = StatusCode::AuthenticationError;
-            str=  "Authentification failed on proxy";
+            str = "Authentication failed on proxy";
             break;
         case NE_CONNECT:
             code = StatusCode::ConnectionProblem;
-            str= "Could not connect to server";
+            str = "Could not connect to server";
             break;
         case NE_TIMEOUT:
             code = StatusCode::ConnectionTimeout;
-            str= "Connection timed out";
+            str = "Connection timed out";
             break;
         case NE_FAILED:
             code = StatusCode::SessionCreationError;
-            str=  "The precondition failed";
+            str = "The precondition failed";
             break;
         case NE_RETRY:
             code = StatusCode::RedirectionNeeded;
-            str= "Retry Request";
+            str = "Retry Request";
             break;
         default:
-            code= StatusCode::UnknowError;
-            str= "Unknow Error from libneon";
+            code = StatusCode::UnknownError;
+            str = "Unknown Error from libneon";
     }
 
     if(!wwwAuth.empty()) {
@@ -153,9 +153,6 @@ void NeonRequest::prepareUriParams() {
     // configure swift params if needed
     if(_params.getProtocol() == RequestProtocol::Swift)
         configureSwiftParams();
-
-    if(_params.getProtocol() == RequestProtocol::CS3)
-        configureRevaParams();
 }
 
 //------------------------------------------------------------------------------
@@ -378,7 +375,7 @@ int NeonRequest::negotiateRequest(DavixError** err){
 
 
                 break;
-            case 401: // authentification requested, do retry
+            case 401: // authentication requested, do retry
             case 403:
                 clearAnswerContent();
 
@@ -646,11 +643,11 @@ void NeonRequest::createError(int ne_status, DavixError **err){
              break;
         case NE_TIMEOUT:
             {
-            // check if redirection occured, if redirection occured
+            // check if redirection occurred, if redirection occurred
             // report TimeoutRedirectionError, to allow error recovery
             if(_current != _orig){
                 code = StatusCode::TimeoutRedirectionError;
-                str= "Connection Timeout during redirection on ";
+                str = "Connection Timeout during redirection on ";
                 str+= _current->getString();
                 break;
             }
